import 'package:flutter/services.dart';

enum EnumMediaType { Label, BlackMark, Journal }

class ZebraPrinter {
  MethodChannel channel;

  Function onPrinterFound;

  Function onPrinterDiscoveryDone;

  Function onChangePrinterStatus;

  ZebraPrinter(String id, this.onPrinterFound, this.onPrinterDiscoveryDone,
      this.onChangePrinterStatus) {
    channel = MethodChannel('ZebraPrinterObject' + id);
    channel.setMethodCallHandler(nativeMethodCallHandler);
  }

  discoveryPrinters() {
    channel.invokeMethod("discoverPrinters");
  }

  setSettings(String settingCommand) {
    channel.invokeMethod("setSetting", {"SettingCommand": settingCommand});
  }

  setDarkness(int darkness) {
    channel.invokeMethod("setSetting", {"Darkness": darkness});
  }

  setMediaType(EnumMediaType mediaType) {
    channel.invokeMethod("setSetting", {"MediaType": mediaType.toString()});
  }

  connectToPrinter(String address) {
    channel.invokeMethod("connectToPrinter", {"Address": address});
  }

  print(String data) {
    channel.invokeMethod("print", {"Data": data});
  }

  Future isPrinterConnected() {
    return channel.invokeMethod("isPrinterConnected");
  }

  Future<dynamic> nativeMethodCallHandler(MethodCall methodCall) async {
    if (methodCall.method == "printerFound") {
      onPrinterFound(methodCall.arguments.toString().split(";")[0],
          methodCall.arguments.toString().split(";")[1]);
    } else if (methodCall.method == "changePrinterStatus") {
      onChangePrinterStatus(
          methodCall.arguments["Status"], methodCall.arguments["Color"]);
    } else if (methodCall.method == "onPrinterDiscoveryDone") {
      onPrinterDiscoveryDone();
    }

    return null;
  }

  String id;
}
